Package: XYomics
Title: Analysis of Sex Differences in Omics Data for Complex Diseases
Version: 0.1.4
Authors@R: 
  c(
    person("Enrico", "Glaab", email = "enrico.glaab@uni.lu", role = c("aut", "cre")),
    person("Sophie", "Le Bars", email = "sophie.lebars@uni.lu", role = "aut"),
    person("Mohamed", "Soudy", email = "mohamed.soudy@uni.lu", role = "aut"),
    person("Murodzhon", "Akhmedov", role = c("cph"))
  )
Maintainer: Enrico Glaab <enrico.glaab@uni.lu>
Description: Tools to analyze sex differences in omics data for complex diseases. It includes functions for differential expression analysis using the 'limma' method <doi:10.1093/nar/gkv007>, interaction testing between sex and disease, pathway enrichment with 'clusterProfiler' <doi:10.1089/omi.2011.0118>, and gene regulatory network (GRN) construction and analysis using 'igraph'. The package enables a reproducible workflow from raw data processing to biological interpretation. 
Depends: R (>= 3.6)
Imports: limma, igraph, edgeR, SeuratObject, Seurat, data.table,
        ggplot2, tidyr, grid, ggraph, dplyr, AnnotationDbi, ggrepel,
        Rcpp, cowplot, patchwork, methods, DESeq2, S4Vectors,
        clusterProfiler
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
Suggests: R.utils, DT, gridExtra, knitr, htmltools, kableExtra,
        rmarkdown, stringr, ReactomePA, org.Hs.eg.db
LinkingTo: Rcpp
VignetteBuilder: knitr, rmarkdown
NeedsCompilation: yes
Packaged: 2026-05-11 12:25:32 UTC; sophie
Author: Enrico Glaab [aut, cre],
  Sophie Le Bars [aut],
  Mohamed Soudy [aut],
  Murodzhon Akhmedov [cph]
Repository: CRAN
Date/Publication: 2026-05-11 16:40:03 UTC
Built: R 4.5.2; x86_64-apple-darwin20; 2026-05-11 19:08:31 UTC; unix
Archs: XYomics.so.dSYM
