# Generated by roxygen2: do not edit by hand

export(PCSF)
export(categorize_sex)
export(categorized_enrich)
export(construct_ppi_pcsf)
export(convert_gene_ids)
export(generate_cat_report)
export(generate_dotplot_sc)
export(generate_violinplot_bulk)
export(get_string_network)
export(get_top_hubs)
export(plot_enrichment_dotplots)
export(plot_network)
export(plot_network_pipeline)
export(plot_volcano_deg)
export(ppi_pipeline)
export(sex_interaction_analysis_bulk)
export(sex_interaction_analysis_sc)
export(sex_interaction_pipeline_sc)
export(sex_stratified_analysis_bulk)
export(sex_stratified_analysis_sc)
export(sex_stratified_pipeline_sc)
export(validate_input_bulk)
export(validate_input_sc)
exportPattern("^[[:alpha:]]+")
import(dplyr)
import(ggplot2)
import(ggraph)
import(ggrepel)
import(grid)
import(limma)
import(patchwork)
import(tidyr)
importFrom(AnnotationDbi,keytypes)
importFrom(Rcpp,evalCpp)
importFrom(Seurat,"Idents<-")
importFrom(Seurat,DefaultAssay)
importFrom(Seurat,DotPlot)
importFrom(Seurat,FindMarkers)
importFrom(Seurat,GetAssayData)
importFrom(Seurat,Idents)
importFrom(SeuratObject,"DefaultAssay<-")
importFrom(SeuratObject,"Idents<-")
importFrom(SeuratObject,DefaultAssay)
importFrom(SeuratObject,Idents)
importFrom(clusterProfiler,dotplot)
importFrom(cowplot,draw_grob)
importFrom(cowplot,draw_plot)
importFrom(cowplot,get_legend)
importFrom(cowplot,ggdraw)
importFrom(data.table,fread)
importFrom(dplyr,"%>%")
importFrom(dplyr,filter)
importFrom(dplyr,mutate)
importFrom(dplyr,slice_min)
importFrom(edgeR,DGEList)
importFrom(edgeR,calcNormFactors)
importFrom(edgeR,filterByExpr)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_minimal)
importFrom(ggrepel,geom_text_repel)
importFrom(igraph,"E<-")
importFrom(igraph,"V<-")
importFrom(igraph,E)
importFrom(igraph,V)
importFrom(igraph,betweenness)
importFrom(igraph,components)
importFrom(igraph,degree)
importFrom(igraph,delete_vertices)
importFrom(igraph,ecount)
importFrom(igraph,edge_attr_names)
importFrom(igraph,ends)
importFrom(igraph,graph.data.frame)
importFrom(igraph,graph_from_data_frame)
importFrom(igraph,induced_subgraph)
importFrom(igraph,is_igraph)
importFrom(igraph,neighbors)
importFrom(igraph,simplify)
importFrom(igraph,vcount)
importFrom(limma,contrasts.fit)
importFrom(limma,eBayes)
importFrom(limma,lmFit)
importFrom(limma,makeContrasts)
importFrom(limma,topTable)
importFrom(limma,voom)
importFrom(methods,slotNames)
importFrom(patchwork,wrap_plots)
importFrom(stats,model.matrix)
importFrom(stats,na.omit)
importFrom(tidyr,pivot_longer)
importFrom(utils,download.file)
useDynLib(XYomics, .registration = TRUE)
