# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

#' Internal function \code{call_sr}
#'
#' This function is internally used to solve the PCST.
#'
#' @keywords internal
#'
#' @param from  A \code{CharacterVector} that corresponds to \code{head} nodes of the edges.
#' @param to A \code{CharacterVector} that corresponds the \code{tail} nodes of the edges.
#' @param cost A \code{NumericVector} which represents the edge weights.
#' @param node_names A \code{CharacterVector} demonstrates the names of the nodes.
#' @param node_prizes A \code{NumericVector} which corresponds to the node prizes.
#' @author Murodzhon Akhmedov
#'
call_sr <- function(from, to, cost, node_names, node_prizes) {
    .Call(`_XYomics_call_sr`, from, to, cost, node_names, node_prizes)
}

