% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sex_interaction_analysis_sc.R
\name{sex_interaction_pipeline_sc}
\alias{sex_interaction_pipeline_sc}
\title{Run sex phenotype interaction analysis pipeline for single cell data}
\usage{
sex_interaction_pipeline_sc(
  seurat_obj,
  target_cell_type_flag = "all",
  sex = "sex",
  phenotype = "status",
  celltype_col = "cell_type",
  min_logfc = 0.25,
  alpha = 0.05,
  sex_labels_vector = c("F", "M"),
  phenotype_labels_vector = c("WT", "TG"),
  min_samples = 20
)
}
\arguments{
\item{seurat_obj}{Seurat object containing single cell data.}

\item{target_cell_type_flag}{Character. Specific cell type to analyze or "all".}

\item{sex}{Character. Metadata column for sex.}

\item{phenotype}{Character. Metadata column for phenotype.}

\item{celltype_col}{Character. Metadata column for cell type.}

\item{min_logfc}{Numeric. Minimum absolute log fold change threshold.}

\item{alpha}{Numeric. FDR threshold for significance.}

\item{sex_labels_vector}{Character vector specifying sex levels.}

\item{phenotype_labels_vector}{Character vector specifying phenotype levels.}

\item{min_samples}{Integer. Minimum number of cells per group (default 20).}
}
\value{
A named list containing interaction analysis results per cell type.
}
\description{
Performs sex phenotype interaction analysis per cell type
using a limma based difference in differences model.
}
