% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ppi_analysis.R
\name{ppi_pipeline}
\alias{ppi_pipeline}
\title{Run PPI PCSf pipeline for single cell DEG categories}
\usage{
ppi_pipeline(result_categories, g, target_cell_type_flag = "all")
}
\arguments{
\item{result_categories}{A named list of data.frames containing DEG results per cell type.
Each data.frame must include DEG_Type, Gene_Symbols, Male_FDR, and Female_FDR.}

\item{g}{An igraph object representing the global protein interaction network.}

\item{target_cell_type_flag}{Character. Specific cell type to analyze or "all".}
}
\value{
A named list containing PCSf networks per cell type and DEG category.
}
\description{
Builds protein protein interaction subnetworks for each cell type
based on DEG categories and FDR derived node prizes.
}
