% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plotting_and_reporting_functions.R
\name{generate_dotplot_sc}
\alias{generate_dotplot_sc}
\title{Generate dotplot of selected genes across groups}
\usage{
generate_dotplot_sc(
  seurat_obj,
  genes,
  sex = "sex",
  phenotype = "status",
  celltype_col = "cell_type",
  target_cell_type_flag = "all"
)
}
\arguments{
\item{seurat_obj}{A Seurat object}

\item{genes}{Character vector of genes to plot}

\item{sex}{Metadata column for sex}

\item{phenotype}{Metadata column for phenotype/status}

\item{celltype_col}{Metadata column for cell types}

\item{target_cell_type_flag}{Either "all" or a specific cell type}
}
\value{
A ggplot object (DotPlot)
}
\description{
Visualizes gene expression across Sex / Phenotype / Cell type combinations.
}
