% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sex_stratified_analysis_sc.R
\name{sex_stratified_pipeline_sc}
\alias{sex_stratified_pipeline_sc}
\title{Run sex stratified differential expression pipeline for single cell data}
\usage{
sex_stratified_pipeline_sc(
  seurat_obj,
  target_cell_type_flag = "all",
  sex = "sex",
  phenotype = "status",
  celltype_col = "cell_type",
  sex_labels_vector = c("F", "M"),
  phenotype_labels_vector = c("WT", "TG"),
  test.use = "wilcox",
  alpha = 0.05,
  beta = 0.5,
  min_abs_logfc = 0.25,
  min_samples = 3
)
}
\arguments{
\item{seurat_obj}{Seurat object containing single cell data.}

\item{target_cell_type_flag}{Character. Cell type to analyze.}

\item{sex}{Character. Metadata column for sex.}

\item{phenotype}{Character. Metadata column for phenotype.}

\item{celltype_col}{Character. Metadata column for cell type.}

\item{sex_labels_vector}{Character vector specifying sex levels.}

\item{phenotype_labels_vector}{Character vector specifying phenotype levels.}

\item{test.use}{Character. Statistical test used in FindMarkers.}

\item{alpha}{Numeric. FDR threshold for significance.}

\item{beta}{Numeric. P value threshold for exclusion in opposite sex.}

\item{min_abs_logfc}{Numeric. Minimum absolute log2 fold change for categorization.}

\item{min_samples}{Integer. Minimum number of cells per group (default 3).}
}
\value{
A named list of categorized differential expression results per cell type.
}
\description{
Performs sex specific differential expression analysis per cell type
and categorizes genes into male specific, female specific, sex dimorphic,
and sex neutral groups.
}
