% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/categorise_sex.R
\name{categorize_sex}
\alias{categorize_sex}
\title{Compute sex-specific differentially expressed genes (DEGs) per category}
\usage{
categorize_sex(
  male_degs,
  female_degs,
  alpha = 0.05,
  beta = 0.5,
  min_abs_logfc = 0.25
)
}
\arguments{
\item{male_degs}{Data frame containing male differential expression results from one specific cell-type or bulk dataset.}

\item{female_degs}{Data frame containing female differential expression results from one specific cell-type or bulk dataset.}

\item{alpha}{Numeric. FDR threshold for significance.}

\item{beta}{Numeric. P-value threshold for excluding genes in opposite sex.}

\item{min_abs_logfc}{Numeric. Minimum absolute log2 fold change threshold.}
}
\value{
Data frame containing categorized DEGs with associated statistics.
}
\description{
Identifies male-specific, female-specific, sex-dimorphic, and sex-neutral DEGs from differential expression results. 
"sex-modulated" requires the interaction mode and is not identified by categorize_sex.
}
