% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sex_stratified_analysis_sc.R
\name{sex_stratified_analysis_sc}
\alias{sex_stratified_analysis_sc}
\title{Perform sex-stratified differential expression analysis for single-cell Seurat object}
\usage{
sex_stratified_analysis_sc(
  seurat_obj,
  sex = "sex",
  phenotype = "status",
  celltype_col = "cell_type",
  sex_labels_vector = c("F", "M"),
  phenotype_labels_vector = c("WT", "TG"),
  test.use = "wilcox",
  min_samples = 3
)
}
\arguments{
\item{seurat_obj}{A Seurat object containing single-cell RNA-seq data.}

\item{sex}{Character. Name of the column in metadata indicating sex.}

\item{phenotype}{Character. Name of the column indicating phenotype/condition.}

\item{celltype_col}{Character. Name of the column indicating cell type.}

\item{sex_labels_vector}{A character vector of length two defining the labels for sex (e.g., c("F", "M")). The first element must correspond to "female" and the second to "male".}

\item{phenotype_labels_vector}{Character vector of length 2 specifying the reference and test phenotypes (e.g., c("WT", "TG")).}

\item{test.use}{Statistical test to use in FindMarkers.}

\item{min_samples}{Integer. Minimum number of cells per group (default 3).}
}
\value{
A list with two elements: `male_DEGs` and `female_DEGs`, each containing a list of DEGs per cell type.
}
\description{
Perform sex-stratified differential expression analysis for single-cell Seurat object
}
